@@ -2,7 +2,8 @@ test_that("Rules Extracted Correctly", {
   # Generate sample data
   set.seed(2021)
   dataset_cont <- generate_cre_dataset(n = 500, rho = 0, n_rules = 2, p = 10,
-                                       effect_size = 0.5, binary = FALSE)
+                                       effect_size = 0.5,
+                                       binary_outcome = FALSE)
   y <- dataset_cont[["y"]]
   z <- dataset_cont[["z"]]
   X <- dataset_cont[["X"]]
@@ -16,11 +17,8 @@ test_that("Rules Extracted Correctly", {
   max_nodes <- 5
   max_depth <- 15
   replace <- FALSE
-  max_decay <- 0.025
-  type_decay <- 2
-
-  # Check for binary outcome
-  binary <- ifelse(length(unique(y)) == 2, TRUE, FALSE)
+  t_decay <- 0.025
+  intervention_vars <- NULL
 
   # Step 1: Split data
   X <- as.matrix(X)
@@ -30,19 +28,17 @@ test_that("Rules Extracted Correctly", {
   ###### Discovery ######
 
   # Step 2: Estimate ITE
-  ite_list <- estimate_ite(y, z, X, ite_method, binary,
+  ite <- estimate_ite(y, z, X, ite_method,
                            include_ps = include_ps,
                            ps_method = ps_method,
-                           oreg_method = oreg_method,
-                           random_state = 376)
-  ite <- ite_list[["ite"]]
-  ite_std <- ite_list[["ite_std"]]
+                           oreg_method = oreg_method)
 
   # Step 3: Generate rules list
-  initial_rules <- generate_rules(X, ite_std, ntrees_rf, ntrees_gbm, node_size,
-                                  max_nodes, max_depth, replace, random_state = 2389)
+  initial_rules <- generate_rules(X, ite, intervention_vars, ntrees_rf,
+                                  ntrees_gbm, node_size, max_nodes, max_depth,
+                                  replace)
 
-  rules <- prune_rules(initial_rules, X, ite_std, max_decay, type_decay)
+  rules <- filter_irrelevant_rules(initial_rules, X, ite, t_decay)
 
 
   ###### Run Tests ######
